summaryrefslogtreecommitdiff
path: root/errors.go
diff options
context:
space:
mode:
Diffstat (limited to 'errors.go')
-rw-r--r--errors.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/errors.go b/errors.go
index 4230c14..9460803 100644
--- a/errors.go
+++ b/errors.go
@@ -143,8 +143,8 @@ var (
// characters length that exceeds the limit.
ErrCellCharsLength = fmt.Errorf("cell value must be 0-%d characters", TotalCellChars)
// ErrOptionsUnzipSizeLimit defined the error message for receiving
- // invalid UnzipSizeLimit and WorksheetUnzipMemLimit.
- ErrOptionsUnzipSizeLimit = errors.New("the value of UnzipSizeLimit should be greater than or equal to WorksheetUnzipMemLimit")
+ // invalid UnzipSizeLimit and UnzipXMLSizeLimit.
+ ErrOptionsUnzipSizeLimit = errors.New("the value of UnzipSizeLimit should be greater than or equal to UnzipXMLSizeLimit")
// ErrSave defined the error message for saving file.
ErrSave = errors.New("no path defined for file, consider File.WriteTo or File.Write")
// ErrAttrValBool defined the error message on marshal and unmarshal